@@ -7,7 +7,7 @@ from __future__ import annotations
 from collections.abc import Sequence, Set
 from typing import Any, Iterable, Union
 
-from referencing import Anchor, Registry, Resource, Specification
+from referencing import Anchor, Registry, Resource, Specification, exceptions
 from referencing._attrs import frozen
 from referencing._core import Resolved as _Resolved, Resolver as _Resolver
 from referencing.typing import URI, Anchor as AnchorType, Mapping
@@ -224,6 +224,50 @@ def _subresources_of_with_crazy_items_dependencies(
     return subresources_of
 
 
+def _subresources_of_with_crazy_aP_items_dependencies(
+    in_value: Set[str] = frozenset(),
+    in_subvalues: Set[str] = frozenset(),
+    in_subarray: Set[str] = frozenset(),
+):
+    """
+    Specifically handle even older drafts where there are some funky keywords.
+    """
+
+    def subresources_of(contents: Schema) -> Iterable[ObjectSchema]:
+        if isinstance(contents, bool):
+            return
+        for each in in_value:
+            if each in contents:
+                yield contents[each]
+        for each in in_subarray:
+            if each in contents:
+                yield from contents[each]
+        for each in in_subvalues:
+            if each in contents:
+                yield from contents[each].values()
+
+        items = contents.get("items")
+        if items is not None:
+            if isinstance(items, Sequence):
+                yield from items
+            else:
+                yield items
+        dependencies = contents.get("dependencies")
+        if dependencies is not None:
+            values = iter(dependencies.values())
+            value = next(values, None)
+            if isinstance(value, Mapping):
+                yield value
+                yield from values
+
+        for each in "additionalItems", "additionalProperties":
+            value = contents.get(each)
+            if isinstance(value, Mapping):
+                yield value
+
+    return subresources_of
+
+
 def _maybe_in_subresource(
     in_value: Set[str] = frozenset(),
     in_subvalues: Set[str] = frozenset(),
@@ -302,6 +346,7 @@ def _maybe_in_subresource_crazy_items_dependencies(
     return maybe_in_subresource
 
 
+#: JSON Schema draft 2020-12
 DRAFT202012 = Specification(
     name="draft2020-12",
     id_of=_dollar_id,
@@ -351,6 +396,7 @@ DRAFT202012 = Specification(
         },
     ),
 )
+#: JSON Schema draft 2019-09
 DRAFT201909 = Specification(
     name="draft2019-09",
     id_of=_dollar_id,
@@ -400,6 +446,7 @@ DRAFT201909 = Specification(
         },
     ),
 )
+#: JSON Schema draft 7
 DRAFT7 = Specification(
     name="draft-07",
     id_of=_legacy_dollar_id,
@@ -433,6 +480,7 @@ DRAFT7 = Specification(
         in_subvalues={"definitions", "patternProperties", "properties"},
     ),
 )
+#: JSON Schema draft 6
 DRAFT6 = Specification(
     name="draft-06",
     id_of=_legacy_dollar_id,
@@ -460,11 +508,12 @@ DRAFT6 = Specification(
         in_subvalues={"definitions", "patternProperties", "properties"},
     ),
 )
+#: JSON Schema draft 4
 DRAFT4 = Specification(
     name="draft-04",
     id_of=_legacy_id,
-    subresources_of=_subresources_of_with_crazy_items_dependencies(
-        in_value={"additionalItems", "additionalProperties", "not"},
+    subresources_of=_subresources_of_with_crazy_aP_items_dependencies(
+        in_value={"not"},
         in_subarray={"allOf", "anyOf", "oneOf"},
         in_subvalues={"definitions", "patternProperties", "properties"},
     ),
@@ -475,11 +524,11 @@ DRAFT4 = Specification(
         in_subvalues={"definitions", "patternProperties", "properties"},
     ),
 )
+#: JSON Schema draft 3
 DRAFT3 = Specification(
     name="draft-03",
     id_of=_legacy_id,
-    subresources_of=_subresources_of_with_crazy_items_dependencies(
-        in_value={"additionalItems", "additionalProperties"},
+    subresources_of=_subresources_of_with_crazy_aP_items_dependencies(
         in_subarray={"extends"},
         in_subvalues={"definitions", "patternProperties", "properties"},
     ),
@@ -544,8 +593,8 @@ class DynamicAnchor:
         last = self.resource
         for uri, registry in resolver.dynamic_scope():
             try:
-                anchor = registry.anchor(uri, self.name)
-            except LookupError:
+                anchor = registry.anchor(uri, self.name).value
+            except exceptions.NoSuchAnchor:
                 continue
             if isinstance(anchor, DynamicAnchor):
                 last = anchor.resource
